@@ -97,6 +97,7 @@ couchTests.replication = function(debug) {
   function populateDb(db, docs, dontRecreateDb) {
     if (dontRecreateDb !== true) {
       db.deleteDb();
+      wait(100);
       db.createDb();
     }
     for (var i = 0; i < docs.length; i++) {
@@ -496,6 +497,15 @@ couchTests.replication = function(debug) {
   } catch (x) {
     TEquals("db_not_found", x.error);
   }
+
+  // validate COUCHDB-317
+  try {
+    CouchDB.replicate("/foobar", "test_suite_db");
+    T(false, "should have failed with db_not_found error");
+  } catch (x) {
+    TEquals("db_not_found", x.error);
+  }
+
   try {
     CouchDB.replicate(CouchDB.protocol + host + "/foobar", "test_suite_db");
     T(false, "should have failed with db_not_found error");
@@ -691,10 +701,10 @@ couchTests.replication = function(debug) {
     TEquals(true, repResult.history instanceof Array);
     TEquals(1, repResult.history.length);
     // NOT 31 (31 is db seq for last doc - the ddoc, which was not replicated)
-    TEquals(30, repResult.source_last_seq);
+    T(31 > repResult.source_last_seq);
     TEquals(0, repResult.history[0].start_last_seq);
-    TEquals(30, repResult.history[0].end_last_seq);
-    TEquals(30, repResult.history[0].recorded_seq);
+    T(31 > repResult.history[0].end_last_seq);
+    T(31 > repResult.history[0].recorded_seq);
     // 16 => 15 docs with even integer field  + 1 doc with string field "7"
     TEquals(16, repResult.history[0].missing_checked);
     TEquals(16, repResult.history[0].missing_found);
@@ -702,6 +712,8 @@ couchTests.replication = function(debug) {
     TEquals(16, repResult.history[0].docs_written);
     TEquals(0, repResult.history[0].doc_write_failures);
 
+    var last_seq = repResult.history[0].end_last_seq;
+
 
     // add new docs to source and resume the same replication
     var newDocs = makeDocs(50, 56);
@@ -740,7 +752,7 @@ couchTests.replication = function(debug) {
     TEquals(36, repResult.source_last_seq);
     TEquals(true, repResult.history instanceof Array);
     TEquals(2, repResult.history.length);
-    TEquals(30, repResult.history[0].start_last_seq);
+    TEquals(last_seq, repResult.history[0].start_last_seq);
     TEquals(36, repResult.history[0].end_last_seq);
     TEquals(36, repResult.history[0].recorded_seq);
     TEquals(3, repResult.history[0].missing_checked);
@@ -1280,6 +1292,7 @@ couchTests.replication = function(debug) {
 
     // delete docs from source
     TEquals(true, sourceDb.deleteDoc(newDocs[0]).ok);
+    wait(1000);
     TEquals(true, sourceDb.deleteDoc(newDocs[6]).ok);
 
     waitForSeq(sourceDb, targetDb);
